import 'package:fc_components/util/adapt.dart';
import 'package:flutter/material.dart';

class FcNavigationBar extends StatefulWidget {
  const FcNavigationBar({
    Key? key,
    required this.items,
    this.currentIndex = 0,
    this.selectedItemColor,
    this.unselectedItemColor,
    this.onTap,
  }) : super(key: key);

  /// 导航元素
  final List<FcNavigationBarItem> items;

  /// 当前选中的元素
  final int currentIndex;

  /// 选中元素颜色
  final Color? selectedItemColor;

  /// 未选中元素颜色
  final Color? unselectedItemColor;

  /// 点击回调
  final void Function(int index)? onTap;

  @override
  _FcNavigationBarState createState() => _FcNavigationBarState();
}

class _FcNavigationBarState extends State<FcNavigationBar> {

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom),
      decoration: BoxDecoration(
        border: Border(
          top: BorderSide(
            color: const Color(0xFF000000).withOpacity(0.1),
            width: Adapt.px(1),
          ),
        ),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: List.generate(widget.items.length, (int index) {
          return _FcNavigationBarTile(
            widget.items[index],
            selected: index == widget.currentIndex,
            selectedIcon: widget.currentIndex,
            selectedItemColor:
                widget.selectedItemColor ?? const Color(0xFFD4052D),
            unselectedItemColor:
                widget.unselectedItemColor ?? const Color(0xFF333333),
            onTap: () {
              if (widget.onTap != null) {
                widget.onTap!(index);
              }
            },
          );
        }),
      ),
    );
  }
}

/// navbar元素
class _FcNavigationBarTile extends StatelessWidget {
  const _FcNavigationBarTile(
    this.info, {
    Key? key,
    required this.selected,
    required this.selectedIcon,
    required this.onTap,
    required this.selectedItemColor,
    required this.unselectedItemColor,
  }) : super(key: key);

  /// navbar元素数据信息
  final FcNavigationBarItem info;

  /// 是否选中
  final bool selected;

  /// 当前选中的
  final dynamic selectedIcon;

  /// 点击回调
  final void Function() onTap;

  /// 选中元素颜色
  final Color selectedItemColor;

  /// 未选中元素颜色
  final Color unselectedItemColor;

  /// 图标 - 计算属性
  Widget get icon {
    return IconTheme(
      data: IconThemeData(
        color: selected ? selectedItemColor : unselectedItemColor,
        size: Adapt.px(50),
      ),
      child: selected ? info.activeIcon : info.icon,
    );
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> list = [icon];
    if (info.label != null) {
      list.add(Padding(
        padding: EdgeInsets.only(top: Adapt.px(3)),
        child: Text(
          info.label!,
          style: TextStyle(
            fontSize: Adapt.px(18),
            fontWeight: FontWeight.w500,
            height: 1.4,
            color: selected ? selectedItemColor : unselectedItemColor,
          ),
        ),
      ));
    }

    return Expanded(
      child: InkWell(
        onTap: onTap,
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: Adapt.px(10)),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: list,
          ),
        ),
      ),
    );
  }
}

/// navbar元素数据
class FcNavigationBarItem {
  const FcNavigationBarItem({
    required this.icon,
    this.label,
    Widget? activeIcon,
    this.backgroundColor,
  }) : activeIcon = activeIcon ?? icon;

  /// 图标
  final Widget icon;

  /// 标题
  final String? label;

  /// 活跃图标
  final Widget activeIcon;

  /// 背景色
  final Color? backgroundColor;
}
